@@ -7,11 +7,12 @@ use warnings;
 use Log::ger;
 
 use List::Util qw(shuffle);
+use Perinci::Sub::Util qw(gen_modified_sub);
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2022-08-20'; # DATE
 our $DIST = 'App-wordlist'; # DIST
-our $VERSION = '0.286'; # VERSION
+our $VERSION = '0.287'; # VERSION
 
 our %SPEC;
 
@@ -167,10 +168,10 @@ sub _word_has_chars_unordered {
 
     for my $i (0..length($chars)-1) {
         my $char = substr($chars, $i, 1);
-        $word =~ s/\Q$char\E//;
+        my $index = index($word, $char);
+        return 0 if $index < 0;
     }
-
-    return length $word ? 0:1;
+    1;
 }
 
 sub _word_has_chars_ordered {
@@ -520,12 +521,12 @@ example, if you have:
 
 (3 letters with the correct position), you can use:
 
-    % wordlist -w EN::Enable '/^tw.s./' --len 5
+    % wordlist -w EN::Wordle '/^tw.s./' --len 5
     twist
 
 or:
 
-    % wordlist -w EN::Enable --chars-ordered tws --len 5
+    % wordlist -w EN::Wordle --chars-ordered tws --len 5
     tawse
     thaws
     ...
@@ -539,7 +540,16 @@ Another example, if you have:
 (2 letters with the incorrect position and 1 letter in the correct position),
 you can use:
 
-    % wordlist -w EN::Enable --chars-unordered wts --len 5 '/^...s.$/'
+    % wordlist -w EN::Wordle --chars-unordered wts --len 5 '/^...s.$/'
+
+Included in the distribution is the <prog:wordlist-wordle> script for
+convenience. This CLI defaults to grepping the "EN::Wordle" wordlist and you
+specify something like `wt_S_` for the pattern (lowercase for letter in
+incorrect position, uppercase for letter in correct position, underscore for
+unguessed):
+
+    % wordlist-wordle 'wt_S_'
+
 _
 };
 sub wordlist {
@@ -882,6 +892,78 @@ sub wordlist {
     }
 }
 
+gen_modified_sub(
+    base_name => 'wordlist',
+    output_name => 'wordlist_wordle',
+    modify_args => {
+        wordlists => sub {
+            $_[0]{default} = ['EN::Wordle'];
+        },
+        len => sub {
+            $_[0]{default} = 5;
+        },
+    },
+    remove_args => [
+        'action',
+        'lcpan',
+        'chars_unordered',
+        'chars_ordered',
+    ],
+    modify_meta => sub {
+        $_[0]{summary} = 'Help solve Wordle';
+        $_[0]{description} = <<'_';
+
+This is a wrapper to <prog:wordlist> designed to be a convenient helper to solve
+Wordle puzzle. By default it greps from the `EN::Wordle` wordlist. It accepts
+5-character pattern like this:
+
+    wt_S_
+
+where lowercase means letter in the incorrect position, uppercase means letter
+in the correct position, and underscore means unguessed. It will convert this
+pattern to regex and the `--chars-unordered` option and pass it to `wordlist`.
+
+_
+        $_[0]{examples} = [
+            {
+                argv => ['wt_S_'],
+                summary => 'W* T* _ S _ (W & T incorrect position, S correct)',
+                test => 0,
+                'x.doc.show_result' => 0,
+            },
+        ];
+    },
+    output_code => sub {
+        my %args = @_;
+
+        $args{arg} //= [];
+        return [400, "I only accept one arg"] if @{ $args{arg} } > 1;
+
+        if (@{ $args{arg} }) {
+            return [400, "Please specify a 5-letter pattern"] if @{ $args{arg} } > 1;
+            my $re = '';
+            my $chars_unordered = '';
+            for my $char (split //, $args{arg}[0]) {
+                if ($char eq '_') {
+                    $re .= '.';
+                } elsif ($char eq uc($char)) {
+                    $re .= quotemeta($char);
+                } else {
+                    $re .= '.';
+                    $chars_unordered .= $char;
+                }
+            }
+            $re = "/\\A$re\\z/";
+            $args{arg} = [$re];
+
+            $args{chars_unordered} = $chars_unordered if length $chars_unordered;
+        }
+
+        log_trace "Arguments passed to wordlist(): %s", \%args;
+        wordlist(%args);
+    },
+);
+
 1;
 # ABSTRACT: Grep words from (or test them against) WordList::*
 
@@ -897,7 +979,7 @@ App::wordlist - Grep words from (or test them against) WordList::*
 
 =head1 VERSION
 
-This document describes version 0.286 of App::wordlist (from Perl distribution App-wordlist), released on 2022-08-20.
+This document describes version 0.287 of App::wordlist (from Perl distribution App-wordlist), released on 2022-08-20.
 
 =head1 SYNOPSIS
 
@@ -1131,6 +1213,119 @@ Select one or more wordlist bundle (Acme::CPANModules::WordListBundle::*) module
 Select one or more wordlist modules.
 
 
+=back
+
+Returns an enveloped result (an array).
+
+First element ($status_code) is an integer containing HTTP-like status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+($reason) is a string containing error message, or something like "OK" if status is
+200. Third element ($payload) is the actual result, but usually not present when enveloped result is an error response ($status_code is not 2xx). Fourth
+element (%result_meta) is called result metadata and is optional, a hash
+that contains extra information, much like how HTTP response headers provide additional metadata.
+
+Return value:  (any)
+
+
+
+=head2 wordlist_wordle
+
+Usage:
+
+ wordlist_wordle(%args) -> [$status_code, $reason, $payload, \%result_meta]
+
+Help solve Wordle.
+
+Examples:
+
+=over
+
+=item * W* T* _ S _ (W & T incorrect position, S correct):
+
+ wordlist_wordle(arg => ["wt_S_"]);
+
+=back
+
+This is a wrapper to L<wordlist> designed to be a convenient helper to solve
+Wordle puzzle. By default it greps from the C<EN::Wordle> wordlist. It accepts
+5-character pattern like this:
+
+ wt_S_
+
+where lowercase means letter in the incorrect position, uppercase means letter
+in the correct position, and underscore means unguessed. It will convert this
+pattern to regex and the C<--chars-unordered> option and pass it to C<wordlist>.
+
+This function is not exported.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<arg> => I<array[str]>
+
+=item * B<color> => I<str> (default: "auto")
+
+When to highlight search stringE<sol>matching pattern with color.
+
+=item * B<detail> => I<bool>
+
+Display more information when listing modulesE<sol>result.
+
+When listing installed modules (C<-l>), this means also returning a wordlist's
+language.
+
+When returning grep result, this means also returning wordlist name.
+
+=item * B<exclude_dynamic_wordlists> => I<bool>
+
+=item * B<exclude_wordlist_pattern> => I<re_from_str>
+
+=item * B<exclude_wordlists> => I<array[str]>
+
+Exclude wordlist modules.
+
+=item * B<ignore_case> => I<bool> (default: 1)
+
+=item * B<langs> => I<array[str]>
+
+Only include wordlists of certain language(s).
+
+By convention, language code is the first subnamespace of a wordlist module,
+e.g. WordList::EN::* for English, WordList::FR::* for French, and so on.
+Wordlist modules which do not follow this convention (e.g. WordList::Password::*
+or WordList::PersonName::*) are not included.
+
+=item * B<len> => I<int> (default: 5)
+
+=item * B<max_len> => I<int>
+
+=item * B<min_len> => I<int>
+
+=item * B<num> => I<int> (default: 0)
+
+Return (at most) this number of words (0 = unlimited).
+
+=item * B<or> => I<bool>
+
+Match any word in query instead of the default "all".
+
+=item * B<random> => I<bool>
+
+Pick random words.
+
+If set to true, then streaming will be turned off. All words will be gathered
+first, then words will be chosen randomly from the gathered list.
+
+=item * B<wordlist_bundles> => I<array[str]>
+
+Select one or more wordlist bundle (Acme::CPANModules::WordListBundle::*) modules.
+
+=item * B<wordlists> => I<array[str]> (default: ["EN::Wordle"])
+
+Select one or more wordlist modules.
+
+
 =back
 
 Returns an enveloped result (an array).
